==> bus-notify-8.0.2-sources.jar: org/miaixz/bus/notify/magic/Material.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2024 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 */
package org.miaixz.bus.notify.magic;

import lombok.Getter;
import lombok.Setter;

import java.util.Map;

/**
 * 消息模版
 *
 * @author Justubborn
 * @since Java 17+
 */
@Getter
@Setter
public class Material {

    /**
     * 地址
     */
    protected String url;
    /**
     * 发送者
     */
    protected String sender;

    /**
     * 接收者
     * 采用','风格
     */
    protected String receive;

    /**
     * 主题
     */
    protected String subject;

    /**
     * 内容  Limit 28K
     */
    protected String content;

    /**
     * 模版/模版ID
     */
    protected String template;

    /**
     * 签名/签名ID
     */
    protected String signature;

    /**
     * 模版参数
     */
    protected String params;

    /**
     * 扩展字段
     */
    protected Map<String, Object> extend;

    /**
     * 内容类型
     */
    protected Type type;

    /**
     * 发送模型
     */
    protected Mode mode;

    public enum Type {
        /**
         * html
         */
        HTML,
        /**
         * 文本
         */
        TEXT,
        /**
         * 语音
         */
        VOICE,
        /**
         * 文件
         */
        FILE,
        /**
         * 文件
         */
        OTHER
    }

    public enum Mode {
        /**
         * 单发
         */
        SINGLE,
        /**
         * 批量
         */
        BATCH
    }

}

==> bus-notify-8.0.3-sources.jar: org/miaixz/bus/notify/magic/Material.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2024 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 */
package org.miaixz.bus.notify.magic;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.SuperBuilder;

import java.util.Map;

/**
 * 消息模版
 *
 * @author Justubborn
 * @since Java 17+
 */
@Getter
@Setter
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class Material {

    /**
     * 地址
     */
    protected String url;
    /**
     * 发送者
     */
    protected String sender;

    /**
     * 接收者
     * 采用','风格
     */
    protected String receive;

    /**
     * 主题
     */
    protected String subject;

    /**
     * 内容  Limit 28K
     */
    protected String content;

    /**
     * 模版/模版ID
     */
    protected String template;

    /**
     * 签名/签名ID
     */
    protected String signature;

    /**
     * 模版参数
     */
    protected String params;

    /**
     * 扩展字段
     */
    protected Map<String, Object> extend;

    /**
     * 内容类型
     */
    protected Type type;

    /**
     * 发送模型
     */
    protected Mode mode;

    public enum Type {
        /**
         * html
         */
        HTML,
        /**
         * 文本
         */
        TEXT,
        /**
         * 语音
         */
        VOICE,
        /**
         * 文件
         */
        FILE,
        /**
         * 文件
         */
        OTHER
    }

    public enum Mode {
        /**
         * 单发
         */
        SINGLE,
        /**
         * 批量
         */
        BATCH
    }

}
